rosrepo
#######

**rosrepo** is a workspace manager for ROS. Under the hood, it runs the
excellent `catkin tools <https://catkin-tools.readthedocs.io/>`_ to build
packages. Additionally, it supports Git operations, can scan Gitlab
servers for available packages, and use these packages to satisfy
dependencies in the workspace.

